

JWInstrument
=================================

.. currentmodule:: webbpsf.webbpsf_core

.. autoclass:: JWInstrument
   :show-inheritance:

   
     
   

   
   

   .. rubric:: Attributes Summary

   .. autosummary::
   
      ~JWInstrument.detector
      ~JWInstrument.image_mask
      ~JWInstrument.options
      ~JWInstrument.pupil_mask

   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~JWInstrument.calcPSF

   
   

   
   

   .. rubric:: Attributes Documentation

   
   .. autoattribute:: detector
   .. autoattribute:: image_mask
   .. autoattribute:: options
   .. autoattribute:: pupil_mask

   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: calcPSF

   
   